psychopy_ext.exp.Task.post_trial — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.post_trial

`Task.` `post_trial`()

  A default function what to do after a trial is over.

  It records the participant’s response as the last key pressed, calculates accuracy based on the expected (correct) response value, and records the time of the last key press with respect to the onset of a trial. If no key was pressed, participant’s response and response time are recorded as an empty string, while accuracy is assigned a ‘No response’.

  Args: | this_trial (dict) A dictionary of trial properties all_keys (list of tuples) A list of tuples with the name of the pressed key and the time of the key press.
  Returns: | this_trial with `subj_resp`, `accuracy`, and `rt` filled in.